# Table of Contents

- [6r](<./6r.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [6R Framework](<./6R-Framework.md>)
  - [Overview](<./6R-Framework/Overview.md>)
  - [What is 6R?](<./6R-Framework/What-is-6R.md>)
  - [How to Implement 6R in SAP LeanIX](<./6R-Framework/How-to-Implement-6R-in-SAP-LeanIX.md>)
  - [Accessing the 6R Attribute in Fact Sheets](<./6R-Framework/Accessing-the-6R-Attribute-in-Fact-Sheets.md>)
  - [Applying the 6R Classification](<./6R-Framework/Applying-the-6R-Classification.md>)
  - [Using the 6R Classification for Application Portfolio Assessment](<./6R-Framework/Using-the-6R-Classification-for-Application-Portfolio-Assessment.md>)
